Pennies
=======

|Build Status| |Coverage|

.. |Version Status| |Downloads| |Pennies Examples| <=== to be added later.

Pythonic Finance Sandbox

LICENSE
-------

New BSD. See `License File <https://github.com/caseyclements/pennies/blob/master/LICENSE>`__.

.. |Build Status| image:: https://api.travis-ci.org/caseyclements/pennies.svg
   :target: https://travis-ci.org/caseyclements/pennies
.. |Coverage| image:: https://coveralls.io/repos/github/caseyclements/pennies/badge.svg
   :target: https://coveralls.io/github/caseyclements/pennies
   :alt: Coverage status
.. |Doc Status| image:: http://readthedocs.org/projects/dask/badge/?version=latest
   :target: https://readthedocs.io/projects/dask/?badge=latest
   :alt: Documentation Status
.. |Gitter| image:: https://badges.gitter.im/Join%20Chat.svg
   :alt: Join the chat at https://gitter.im/dask/dask
   :target: https://gitter.im/dask/dask?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
.. |Version Status| image:: https://img.shields.io/pypi/v/dask.svg
   :target: https://pypi.python.org/pypi/dask/
.. |Downloads| image:: https://img.shields.io/pypi/dm/dask.svg
   :target: https://pypi.python.org/pypi/dask/
.. |Pennies Examples| image:: http://mybinder.org/badge.svg
   :alt: Pennies Example Notebooks
   :target: http://mybinder.org/repo/dask/dask-examples
